@@ -239,8 +239,6 @@ sub cleanup_conf_line {
             $repo =~ s(^\./)();
             next if $repo =~ m(/$);
                 # tolerate non-bare repos within ~/repositories but silently ignore them
-            next unless update_hook_present($repo);
-                # ignore repos that don't yet have the update hook
             push @phy_repos, $repo;
         }
         trace( 3, scalar(@phy_repos) . " physical repos found" );
@@ -363,7 +361,7 @@ sub ssh_fingerprint_file {
     my $in = shift;
     -f $in or die "file not found: $in\n";
     my $fh;
-    open( $fh, "ssh-keygen -l -f $in |" ) or die "could not fork: $!\n";
+    open( $fh, "ssh-keygen -l -f $in 2>&1 |" ) or die "could not fork: $!\n";
     my $output = <$fh>;
     chomp $output;
     # dbg("fp = $fp");
